@@ -71,12 +71,12 @@ class PlotMixin(object):
         plt.tight_layout()
         return fig
 
-    def plot_data_matrix(self, figsize=(12, 6), show_days=False):
+    def plot_data_matrix(self, figsize=(12, 6), show_days=False, units='kW'):
         with sns.axes_style("white"):
             fig, ax = plt.subplots(nrows=1, figsize=figsize, sharex=True)
             foo = ax.imshow(self._power_signals_d, cmap='hot', interpolation='none', aspect='auto')
             ax.set_title('Measured power')
-            plt.colorbar(foo, ax=ax, label='kW')
+            plt.colorbar(foo, ax=ax, label=units)
             ax.set_xlabel('Day number')
             ax.set_yticks([])
             ax.set_ylabel('(sunset)        Time of day        (sunrise)')
@@ -92,7 +92,8 @@ class PlotMixin(object):
                 ax.set_ylim(*ylim)
         return fig
 
-    def plot_measured_clear_matrices(self, figsize=(12, 10), show_days=False):
+    def plot_measured_clear_matrices(self, figsize=(12, 10), show_days=False,
+                                     units='kW'):
         with sns.axes_style("white"):
             fig, ax = plt.subplots(nrows=2, figsize=figsize, sharex=True)
             foo = ax[0].imshow(self._power_signals_d, cmap='hot', interpolation='none', aspect='auto')
@@ -100,8 +101,8 @@ class PlotMixin(object):
             bar = ax[1].imshow(self.clear_sky_signals(), cmap='hot',
                                vmin=0, vmax=np.max(self._power_signals_d), interpolation='none', aspect='auto')
             ax[1].set_title('Estimated clear sky power')
-            plt.colorbar(foo, ax=ax[0], label='kW')
-            plt.colorbar(bar, ax=ax[1], label='kW')
+            plt.colorbar(foo, ax=ax[0], label=units)
+            plt.colorbar(bar, ax=ax[1], label=units)
             ax[1].set_xlabel('Day number')
             ax[0].set_yticks([])
             ax[0].set_ylabel('(sunset)   Time of day   (sunrise)')
